==> jwinner-base-0.0.3-sources.jar: itez/plat/base/model/base/BaseComp.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseComp<M extends BaseComp<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setModuleIds(java.lang.String moduleIds) {
		set("moduleIds", moduleIds);
		return (M)this;
	}
	
	public java.lang.String getModuleIds() {
		return getStr("moduleIds");
	}

	public M setAddr(java.lang.String addr) {
		set("addr", addr);
		return (M)this;
	}
	
	public java.lang.String getAddr() {
		return getStr("addr");
	}

	public M setPosition(java.lang.String position) {
		set("position", position);
		return (M)this;
	}
	
	public java.lang.String getPosition() {
		return getStr("position");
	}

	public M setPost(java.lang.String post) {
		set("post", post);
		return (M)this;
	}
	
	public java.lang.String getPost() {
		return getStr("post");
	}

	public M setTel(java.lang.String tel) {
		set("tel", tel);
		return (M)this;
	}
	
	public java.lang.String getTel() {
		return getStr("tel");
	}

	public M setEmail(java.lang.String email) {
		set("email", email);
		return (M)this;
	}
	
	public java.lang.String getEmail() {
		return getStr("email");
	}

	public M setWebsite(java.lang.String website) {
		set("website", website);
		return (M)this;
	}
	
	public java.lang.String getWebsite() {
		return getStr("website");
	}

	public M setLogoMini(java.lang.String logoMini) {
		set("logoMini", logoMini);
		return (M)this;
	}
	
	public java.lang.String getLogoMini() {
		return getStr("logoMini");
	}

	public M setLogoFull(java.lang.String logoFull) {
		set("logoFull", logoFull);
		return (M)this;
	}
	
	public java.lang.String getLogoFull() {
		return getStr("logoFull");
	}

	public M setWechat(java.lang.String wechat) {
		set("wechat", wechat);
		return (M)this;
	}
	
	public java.lang.String getWechat() {
		return getStr("wechat");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setIndex(java.lang.String index) {
		set("index", index);
		return (M)this;
	}
	
	public java.lang.String getIndex() {
		return getStr("index");
	}

	public M setSelfTemp(java.lang.Integer selfTemp) {
		set("selfTemp", selfTemp);
		return (M)this;
	}
	
	public java.lang.Integer getSelfTemp() {
		return getInt("selfTemp");
	}

	public M setSelfTempExp(java.lang.String selfTempExp) {
		set("selfTempExp", selfTempExp);
		return (M)this;
	}
	
	public java.lang.String getSelfTempExp() {
		return getStr("selfTempExp");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.0.5-sources.jar: itez/plat/base/model/base/BaseComp.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseComp<M extends BaseComp<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setIdNum(java.lang.String idNum) {
		set("idNum", idNum);
		return (M)this;
	}
	
	public java.lang.String getIdNum() {
		return getStr("idNum");
	}

	public M setNum(java.lang.String num) {
		set("num", num);
		return (M)this;
	}
	
	public java.lang.String getNum() {
		return getStr("num");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setModules(java.lang.String modules) {
		set("modules", modules);
		return (M)this;
	}
	
	public java.lang.String getModules() {
		return getStr("modules");
	}

	public M setAddr(java.lang.String addr) {
		set("addr", addr);
		return (M)this;
	}
	
	public java.lang.String getAddr() {
		return getStr("addr");
	}

	public M setPosition(java.lang.String position) {
		set("position", position);
		return (M)this;
	}
	
	public java.lang.String getPosition() {
		return getStr("position");
	}

	public M setPost(java.lang.String post) {
		set("post", post);
		return (M)this;
	}
	
	public java.lang.String getPost() {
		return getStr("post");
	}

	public M setTel(java.lang.String tel) {
		set("tel", tel);
		return (M)this;
	}
	
	public java.lang.String getTel() {
		return getStr("tel");
	}

	public M setEmail(java.lang.String email) {
		set("email", email);
		return (M)this;
	}
	
	public java.lang.String getEmail() {
		return getStr("email");
	}

	public M setWebsite(java.lang.String website) {
		set("website", website);
		return (M)this;
	}
	
	public java.lang.String getWebsite() {
		return getStr("website");
	}

	public M setLogoMini(java.lang.String logoMini) {
		set("logoMini", logoMini);
		return (M)this;
	}
	
	public java.lang.String getLogoMini() {
		return getStr("logoMini");
	}

	public M setLogoFull(java.lang.String logoFull) {
		set("logoFull", logoFull);
		return (M)this;
	}
	
	public java.lang.String getLogoFull() {
		return getStr("logoFull");
	}

	public M setWechat(java.lang.String wechat) {
		set("wechat", wechat);
		return (M)this;
	}
	
	public java.lang.String getWechat() {
		return getStr("wechat");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setIndex(java.lang.String index) {
		set("index", index);
		return (M)this;
	}
	
	public java.lang.String getIndex() {
		return getStr("index");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
